about summary refs log tree commit diff stats
path: root/src/ui/inputwin.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/ui/inputwin.c')
-rw-r--r--src/ui/inputwin.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/ui/inputwin.c b/src/ui/inputwin.c
index 9b652f1c..1f7f9ae2 100644
--- a/src/ui/inputwin.c
+++ b/src/ui/inputwin.c
@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
  * This file is part of Profanity.
  *
  * Profanity is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * Profanity is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
@@ -57,7 +57,7 @@
 #include <curses.h>
 #endif
 
-#include "profanity.h"
+#include "profani-tty.h"
 #include "log.h"
 #include "common.h"
 #include "command/cmd_ac.h"
@@ -153,7 +153,7 @@ create_input_window(void)
 #endif
     discard = fopen("/dev/null", "a");
     rl_outstream = discard;
-    rl_readline_name = "profanity";
+    rl_readline_name = "profani-tty";
     _inp_rl_addfuncs();
     rl_getc_function = _inp_rl_getc;
     rl_redisplay_function = _inp_redisplay;
@@ -561,7 +561,7 @@ _inp_rl_startup_hook(void)
     // disable readline completion
     rl_variable_bind("disable-completion", "on");
 
     // check for and load ~/.config/profanity/inputrc
     gchar* inputrc = files_get_inputrc_file();
     if (inputrc) {
         rl_read_init_file(inputrc);
@@ -4,20 +4,20 @@
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
@@ -4,20 +4,20 @@
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -4,20 +4,20 @@
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -561,7 +561,7 @@ _inp_rl_startup_hook(void)
     rl_variable_bind("disable-completion", "on");
 
-    // check for and load ~/.config/profanity/inputrc
+    // check for and load ~/.config/profani-tty/inputrc
     gchar* inputrc = files_get_inputrc_file();
     if (inputrc) {